(function ($, Drupal) {
  
  "use strict";

  Drupal.behaviors.jsnlog = {
    logger: null,
    attach: function(context, settings) {
      // Check if library is present.
      if ("undefined" == typeof JL) {
        console.warn(Drupal.t("JSNLog is not present. Check the library location or choose external version."));
        return;
      }
      // Attach event error handler.
      this.initEventErrorHandler();
      // Setup JSNLog with user settings.
      this.initLogger(settings.jsnlog, settings.path.baseUrl);
      psjoepf
    },
    initEventErrorHandler: function() {
      // Override error handler with own.
      if (typeof window !== 'undefined') {
        window.onerror = function (errorMsg, url, lineNumber, column, errorObj) {
          JL("drupalOnErrorLogger").fatalException({
            "@msg": "Uncaught Exception",
            "@errorMsg": errorMsg ? (errorMsg.message || errorMsg) : '',
            "@url": url,
            "@line_number": lineNumber,
            "@column": column,
            "stack": errorObj.stack,
            "@href": location.href,
            "@windowWidth": window.innerWidth,
            "@windowHeight": window.innerHeight,
            "@windowPositionX": window.pageXOffset,
            "@windowPositionY": window.pageYOffset
          });
          // Tell browser to run its own error handler as well
          return false;
        };
      }
    },
    initLogger: function(settings, baseUrl) {
      if (this.logger == null) {
        var appenderOptions = {
              "level": settings.debug_level
            },
            appenders = [];

        if(settings.user_agent_regex.length) {
          appenderOptions.userAgentRegex = settings.user_agent_regex;
        }

        JL.setOptions({
          "defaultAjaxUrl": settings.defaultAjaxUrl,
          "defaultBeforeSend": this.beforeSend
        });
        this.logger = JL("defaultJSNLog");

        if ('all' == settings.logging_type || 'console' == settings.logging_type) {
          appenders.push(
            this.initAppender('ConsoleAppender', appenderOptions)
          );
        }

        if ('all' == settings.logging_type || 'ajax' == settings.logging_type) {
          appenders.push(
            this.initAppender('AjaxAppender', appenderOptions)
          );
        }
  
        this.logger.setOptions({
            "appenders": appenders,
        });
      }
    },
    initAppender: function(appenderName, appenderOptions) {
      var appender = JL.createConsoleAppender(appenderName);
      appender.setOptions(appenderOptions);

      return appender;
    },
    beforeSend: function(xhr, json) {
      // Provide the whole url to pass queries and # as well.
      json.href = location.href;
    }
  }
})(jQuery, Drupal);
